@@ -1,41 +1,36 @@
 import asyncio
-import re
 from typing import Callable, Tuple, Union
 
-from telegrambotclient.base import CallbackQuery, MessageField, UpdateField
+from telegrambotclient.base import MessageField, UpdateField
 
 
 class UpdateHandler:
-    __slots__ = ("_callback", "_update_field")
+    __slots__ = ("callback", "update_field")
 
     def __init__(self, callback: Callable, update_field: Union[UpdateField,
                                                                str]):
-        self._callback = callback
-        self._update_field = update_field.value if isinstance(
+        self.callback = callback
+        self.update_field = update_field.value if isinstance(
             update_field, UpdateField) else update_field
 
     @property
-    def name(self):
-        return "{0}.{1}".format(self._callback.__module__,
-                                self._callback.__name__)
-
-    @property
-    def update_field(self) -> str:
-        return self._update_field
+    def callback_name(self):
+        return "{0}.{1}".format(self.callback.__module__,
+                                self.callback.__name__)
 
     def __repr__(self) -> str:
-        return self.name
+        return self.callback_name
 
     async def __call__(self, *args, **kwargs):
-        return await self._callback(
+        return await self.callback(
             *args, **kwargs) if asyncio.iscoroutinefunction(
-                self._callback) else self._callback(*args, **kwargs)
+                self.callback) else self.callback(*args, **kwargs)
 
 
 class ErrorHandler(UpdateHandler):
     __slots__ = ("errors", )
 
-    def __init__(self, callback: Callable, errors: Tuple = None):
+    def __init__(self, callback: Callable, errors=None):
         super().__init__(callback=callback, update_field="error")
         self.errors = errors or (Exception, )
 
@@ -108,42 +103,16 @@ class EditedChannelPostHandler(_MessageHandler):
 
 
 class CallbackQueryHandler(UpdateHandler):
-    __slots__ = ("callback_data", "callback_data_name",
-                 "callback_data_patterns", "callback_data_parser",
-                 "game_short_name", "_kwargs")
+    __slots__ = ("data", )
 
     def __init__(self,
                  callback: Callable,
                  callback_data: str = None,
-                 callback_data_name: str = None,
-                 callback_data_regex: Tuple[str] = None,
-                 callback_data_parser: Callable = None,
-                 game_short_name: str = None,
-                 **kwargs):
+                 game_short_name: str = None):
         super().__init__(callback=callback,
                          update_field=UpdateField.CALLBACK_QUERY)
-        self.callback_data = callback_data
-        self.callback_data_name = callback_data_name
-        self.callback_data_patterns = tuple(
-            re.compile(regex) for regex in callback_data_regex) if isinstance(
-                callback_data_regex, tuple) else ()
-        self.callback_data_parser = callback_data_parser
-        self.game_short_name = game_short_name
-        self._kwargs = kwargs
-
-    def match_callback_data(self, callback_query: CallbackQuery):
-        for pattern in self.callback_data_patterns:
-            if isinstance(callback_query.data, str):
-                result = pattern.match(callback_query.data)
-                if result:
-                    return result
-        return None
-
-    def parse_callback_data(self, callback_query: CallbackQuery):
-        if self.callback_data_parser:
-            return self.callback_data_parser(callback_query.data,
-                                             **self._kwargs)
-        return False
+        self.data = callback_data or game_short_name
+        assert bool(self.data), True
 
 
 class InlineQueryHandler(UpdateHandler):
@@ -186,20 +155,3 @@ class MyChatMemberHandler(UpdateHandler):
 class ChatMemberHandler(UpdateHandler):
     def __init__(self, callback: Callable):
         super().__init__(callback, update_field=UpdateField.CHAT_MEMBER)
-
-
-HandlerMapping = {
-    UpdateField.MESSAGE: MessageHandler,
-    UpdateField.EDITED_MESSAGE: EditedMessageHandler,
-    UpdateField.CHANNEL_POST: ChannelPostHandler,
-    UpdateField.EDITED_CHANNEL_POST: EditedChannelPostHandler,
-    UpdateField.INLINE_QUERY: InlineQueryHandler,
-    UpdateField.CHOSEN_INLINE_RESULT: ChosenInlineResultHandler,
-    UpdateField.CALLBACK_QUERY: CallbackQueryHandler,
-    UpdateField.SHIPPING_QUERY: ShippingQueryHandler,
-    UpdateField.PRE_CHECKOUT_QUERY: PreCheckoutQueryHandler,
-    UpdateField.POLL: PollHandler,
-    UpdateField.POLL_ANSWER: PollAnswerHandler,
-    UpdateField.MY_CHAT_MEMBER: MyChatMemberHandler,
-    UpdateField.CHAT_MEMBER: ChatMemberHandler
-}
